@@ -1,6 +1,6 @@
 package FvwmPiazza::Tiler;
-BEGIN {
-  $FvwmPiazza::Tiler::VERSION = '0.2002';
+{
+  $FvwmPiazza::Tiler::VERSION = '0.2003';
 }
 use strict;
 
@@ -10,7 +10,7 @@ FvwmPiazza::Tiler - Fvwm module for tiling windows.
 
 =head1 VERSION
 
-version 0.2002
+version 0.2003
 
 =head1 SYNOPSIS
 
@@ -98,6 +98,8 @@ sub init {
 
     $self->{all_windows} = {};
     $self->{current_group} = undef;
+    my $maximize_val = $self->{configTracker}->data('UseMaximize');
+    $self->{maximize} = ($maximize_val =~ /(1|true|on)/i);
     $self->{desks} = {};
     $self->{Layouts} = {};
     foreach my $lay ($self->layouts())
@@ -304,7 +306,9 @@ sub observe_window_addition {
        $self->debug("Not Interested in window $wid");
        return 0;
     }
-    my $new_window = FvwmPiazza::GroupWindow->new(ID=>$wid);
+    my $new_window = FvwmPiazza::GroupWindow->new(
+        ID=>$wid,
+        MAXIMIZE=>$self->{maximize});
     $self->{all_windows}->{$wid} = $new_window;
     $self->manage_window(window=>$wid);
 } # observe_window_addition
@@ -630,8 +634,11 @@ sub apply_tiling {
     #
     if (($layout eq 'None'))
     {
-	$self
-	->postponeSend("All (CurrentPage, Maximizable) Maximize False");
+        if ($self->{maximize})
+        {
+            $self
+                ->postponeSend("All (CurrentPage, Maximizable) Maximize False");
+        }
 
 	delete $self->{desks}->{$desk}->{$pagex}->{$pagey};
 	$self->init_new_page(desk_n=>$desk,
@@ -826,6 +833,7 @@ sub init_new_page {
 		      DESK=>$pwin->{desk},
 		      PAGEX=>$pwin->{page_nx},
 		      PAGEY=>$pwin->{page_ny},
+                      MAXIMIZE=>$self->{maximize},
 		     );
 	    $self->{all_windows}->{$wid} = $new_window;
 	    push @windows, $new_window;
@@ -1062,4 +1070,4 @@ under the same terms as Perl itself.
 =cut
 
 1; # End of FvwmPiazza::Tiler
-__END__
\ No newline at end of file
+__END__
